summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabeldict/searchengine.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /kbabel/kbabeldict/searchengine.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/kbabeldict/searchengine.h')
-rw-r--r--kbabel/kbabeldict/searchengine.h42
1 files changed, 22 insertions, 20 deletions
diff --git a/kbabel/kbabeldict/searchengine.h b/kbabel/kbabeldict/searchengine.h
index a10e6193..f14baa1e 100644
--- a/kbabel/kbabeldict/searchengine.h
+++ b/kbabel/kbabeldict/searchengine.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -91,7 +91,7 @@ public:
TQString projectContext;
/**
- * Status of the translation, for example "approved", "spellchecked", "unknown"
+ * tqStatus of the translation, for example "approved", "spellchecked", "unknown"
*/
TQString status;
@@ -167,13 +167,13 @@ class KDE_EXPORT SearchFilter
public:
SearchFilter() :
_projects()
- , _location( TQString::null )
- , _languageCode( TQString::null )
- , _origLanguageCode( TQString::null )
+ , _location( TQString() )
+ , _languageCode( TQString() )
+ , _origLanguageCode( TQString() )
, _translators()
, _projectKeywords()
, _projectContexts()
- , _translationStatus()
+ , _translationtqStatus()
{}
virtual ~SearchFilter() {}
@@ -213,10 +213,10 @@ public:
void setProjectContext( const TQStringList& projectContexts) { _projectContexts = projectContexts; }
/**
- * Status of the translation, for example "approved", "spellchecked", "unknown"
+ * tqStatus of the translation, for example "approved", "spellchecked", "unknown"
*/
- void setStatus( const TQString& translationStatus) { _translationStatus = translationStatus; }
- void setStatus( const TQStringList& translationStati) { _translationStatus = translationStati; }
+ void settqStatus( const TQString& translationtqStatus) { _translationtqStatus = translationtqStatus; }
+ void settqStatus( const TQStringList& translationStati) { _translationtqStatus = translationStati; }
/**
* The key method of the class - check, if the argument
@@ -232,7 +232,7 @@ private:
TQStringList _translators;
TQStringList _projectKeywords ;
TQStringList _projectContexts;
- TQStringList _translationStatus;
+ TQStringList _translationtqStatus;
};
/**
@@ -241,12 +241,13 @@ private:
* necessary function. The widget should not be bigger than 400x400.
* If you need more space, you maybe want to use a tabbed widget.
*/
-class KDE_EXPORT PrefWidget : public QWidget
+class KDE_EXPORT PrefWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- PrefWidget(TQWidget *parent, const char* name=0);
+ PrefWidget(TQWidget *tqparent, const char* name=0);
virtual ~PrefWidget();
public slots:
@@ -265,12 +266,13 @@ public slots:
};
-class KDE_EXPORT SearchEngine : public QObject
+class KDE_EXPORT SearchEngine : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- SearchEngine(TQObject *parent=0, const char *name=0);
+ SearchEngine(TQObject *tqparent=0, const char *name=0);
virtual ~SearchEngine();
@@ -306,7 +308,7 @@ public:
virtual TQString searchTranslation(const TQString&, int &score, const uint pluralForm = 0) {
Q_UNUSED(pluralForm);
- score = 0; return TQString::null;
+ score = 0; return TQString();
}
/**
@@ -316,7 +318,7 @@ public:
virtual TQString fuzzyTranslation(const TQString& /*text*/, int &score, const uint pluralForm = 0) {
Q_UNUSED(pluralForm);
- score = 0; return TQString::null; };
+ score = 0; return TQString(); };
/**
@@ -352,9 +354,9 @@ public:
* search engine. The returned widget should not be bigger than
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
* @param parent the parent of the returned widget
*/
- virtual PrefWidget* preferencesWidget(TQWidget *parent)=0;
+ virtual PrefWidget* preferencesWidget(TQWidget *tqparent)=0;
/** @returns information about this SearchEngine */
virtual const KAboutData *about() const= 0;
@@ -352,9 +354,9 @@ public:
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
- * @param parent the parent of the returned widget
+ * @param tqparent the tqparent of the returned widget
*/